@@ -5,8 +5,8 @@ from urllib.parse import quote
 import gunicorn.app.base
 from whitenoise import WhiteNoise
 
-from .request import Request
-from .utils import make_active_helper
+from .utils.active import make_active_helper
+from .utils.request import Request
 
 
 def _get_local_ip():
@@ -85,7 +85,9 @@ class WSGIApp:
 
     def call(self, request):
         path = request.path
+        print(path)
         if not self.clay.file_exists(path):
+            print("file doesnt exists", path)
             path += "/index.html"
             if not self.clay.file_exists(path):
                 return self.not_found(request)
@@ -94,6 +96,7 @@ class WSGIApp:
         if request.method == "HEAD":
             body = ""
         else:
+            print("rendering file", path)
             body = self.clay.render_file(path, request=request, active=active)
         mime = mimetypes.guess_type(path)[0] or "text/plain"
         response_headers = [("Content-Type", mime)]
@@ -103,6 +106,7 @@ class WSGIApp:
         mime = "text/plain"
         body = f"File {request.path} not found."
         active = make_active_helper(request)
+
         for path in ["not-found.html", "_notfound.html", "404.html"]:
             if self.clay.file_exists(path):
                 mime = "text/html"
@@ -122,7 +126,6 @@ class WSGIApp:
         server = GunicornMiddleware(
             self,
             bind=f"{host}:{port}",
-            worker_class="eventlet",
             accesslog="-",
             access_log_format="%(h)s %(m)s %(U)s -> HTTP %(s)s",
             on_starting=on_starting
